' ***************************************************************
' VB Script
' 1. Check OS
' 2. Check platform (Shark Bay, Chief River or Bay Trail-M).
' 3. Set reg value to avoid MS BT Stack issue on Win7.
'
' 2014/03/14 Ver 1.2
' ***************************************************************

Option Explicit
'On Error Resume Next

' ---------------------------------------------------------------
' 0. Initialize objects.
' ---------------------------------------------------------------
Dim oPlatformTypeHash
Set oPlatformTypeHash = WScript.CreateObject("Scripting.Dictionary")
' SharkBay DeviceID 8Cxx
oPlatformTypeHash.Add "8C", GetRef("SetRegValueForSharkBay")
' SharkBay DeviceID 9Cxx
oPlatformTypeHash.Add "9C", GetRef("SetRegValueForSharkBay")
' ChiefRiver DeviceID 1Exx
oPlatformTypeHash.Add "1E", GetRef("SetRegValueForChiefRiver")
' Bay Trail-M DeviceID 0Fxx
oPlatformTypeHash.Add "0F", GetRef("SetRegValueForBayTrail")

' ---------------------------------------------------------------
' 1. Check OS (Win7 or others).
' ---------------------------------------------------------------
If IsWindows7 <> True Then
	WScript.Quit 0
End If
' ---------------------------------------------------------------
' 2. Check platform (Shark Bay, Chief River or Bay Trail-M).
' ---------------------------------------------------------------
Dim oPlatformType
oPlatformType = GetPlatformType(oPlatformTypeHash)
If IsEmpty(oPlatformType) = True Then
	WScript.Quit 0
End If
'WScript.Echo "Platform: " & oPlatformType
' ---------------------------------------------------------------
' 3. Add reg value to avoid the MS BT Stack issue on Win7.
' ---------------------------------------------------------------
Dim oInvoke
Set oInvoke = oPlatformTypeHash(oPlatformType)
Dim oResult
oResult = oInvoke
'WScript.Echo "Result: " & oResult
WScript.Quit 0

' ---------------------------------------------------------------
' 1. Check OS (Win7 or others).
' ---------------------------------------------------------------
Function IsWindows7()
	Dim oService
	Set oService = WScript.CreateObject("WbemScripting.SWbemLocator").ConnectServer

	Dim oClassSet
	Set oClassSet = oService.ExecQuery("SELECT * FROM Win32_OperatingSystem " _
											& "WHERE Version LIKE '6.1%'")
	If oClassSet.Count = 0 Then
		IsWindows7 = False
	Else
		IsWindows7 = True
	End If
End Function

' ---------------------------------------------------------------
' 2. Check platform (Shark Bay, Chief River or Bay Trail-M).
' ---------------------------------------------------------------
Function GetPlatformType(hash)
	Dim oService
	Set oService = GetObject("winmgmts:\\" & "." & "\root\cimv2")
	
	Dim oKey
	For Each oKey In hash.Keys
		Dim oClassSet
		Set oClassSet = oService.ExecQuery("SELECT * FROM Win32_PnPEntity " _
											& "WHERE Service='msisadrv' "_
											& "AND PNPDeviceID LIKE 'PCI\\VEN_8086&DEV_" _
											& oKey _
											& "%'")
		If oClassSet.Count <> 0 Then
			GetPlatformType = oKey
			Exit For
		End If
	Next
End Function

' ---------------------------------------------------------------
' 3. Add reg value to avoid the MS BT Stack issue on Win7.
' ---------------------------------------------------------------
' For SharkBay
Function SetRegValueForSharkBay()
	Dim oService
	Set oService = WScript.CreateObject("WbemScripting.SWbemLocator")_
											.ConnectServer(, "root\default")
	Dim oRegClass
	Set oRegClass = oService.Get("StdRegProv")
	
	Const HKLM = &H80000002
	Const REG_KEY_USBFLAGS = "SYSTEM\CurrentControlSet\Control\UsbFlags"
	Dim oSubKeySet
	oRegClass.EnumKey HKLM, REG_KEY_USBFLAGS, oSubKeySet
	
	SetRegValueForSharkBay = False
	Dim oSubKey
	For Each oSubKey In oSubKeySet
		Dim oTargetID
		oTargetID = Mid(oSubKey, 1, 8)
		
		If (oTargetID = "80878000") Or (oTargetID = "80878008") Then
			SetRegValueForSharkBay = SetRegBinValue(oRegClass, oSubKey)
		End If
	Next
End Function

' For ChiefRiver
Function SetRegValueForChiefRiver()
	Dim oService
	Set oService = WScript.CreateObject("WbemScripting.SWbemLocator")_
											.ConnectServer(, "root\default")
	Dim oRegClass
	Set oRegClass = oService.Get("StdRegProv")
	
	Const REG_SUBKEY = "808700240000"
	SetRegValueForChiefRiver = SetRegBinValue(oRegClass, REG_SUBKEY)
End Function

' For Bay Trail-M
Function SetRegValueForBayTrail()
	Dim oService
	Set oService = WScript.CreateObject("WbemScripting.SWbemLocator")_
											.ConnectServer(, "root\default")
	Dim oRegClass
	Set oRegClass = oService.Get("StdRegProv")
	
	Const HKLM = &H80000002
	Const REG_KEY_USBFLAGS = "SYSTEM\CurrentControlSet\Control\UsbFlags"
	Dim oSubKeySet
	oRegClass.EnumKey HKLM, REG_KEY_USBFLAGS, oSubKeySet
	
	SetRegValueForBayTrail = False
	Dim oSubKey
	For Each oSubKey In oSubKeySet
		Dim oTargetID
		oTargetID = Mid(oSubKey, 1, 8)
		
		If (oTargetID = "808707E6") Then
			SetRegValueForBayTrail = SetRegBinValue(oRegClass, oSubKey)
		End If
	Next
End Function

' Set Registry
Function SetRegBinValue(oRegClass, oSubKeyPart)
	Const HKLM = &H80000002
	Const REG_KEY_PART = "SYSTEM\CurrentControlSet\Control\UsbFlags\"
	Const REG_VALUE_NAME = "NoClearTTBufferOnCancel"
	Dim REG_VALUE
	REG_VALUE = Array(&H01)
	
	Dim oResult
	oResult = oRegClass.SetBinaryValue(HKLM, (REG_KEY_PART & oSubKeyPart), _
											REG_VALUE_NAME, REG_VALUE)
	If oResult = 0 Then
		SetRegBinValue = True
	Else
		SetRegBinValue = False
	End If
End Function
